import { ReactNode } from 'react';
type OpenType = string | false;
type ContentType = {
    id: string;
    header: ReactNode;
    details: ReactNode;
    disabled?: boolean;
};
type StyleOverrides = {
    background: string;
    color: string;
    divider: string;
};
type AccordionProps = {
    className?: string;
    /** Array of objects to render the accordion headers and content */
    content: ContentType[];
    /** Uncontrolled prop: opens all folds initially. Only works if uncontrolled. */
    defaultExpanded?: boolean;
    /** Controlled prop: set which panel is open yourself */
    open?: OpenType;
    /** Controlled prop: the change handler fn to set the `open` state on header click */
    setOpen?: (open: OpenType) => void;
    /** Disables entire accordion */
    disabled?: boolean;
    /** Sets rounded or square corners */
    square?: boolean;
    /** adds padding to the header and details */
    withPadding?: boolean;
    ['data-testid']?: string;
    /** Style overrides for the accordion */
    styleOverrides?: StyleOverrides;
    /** Icon to use for the expand/collapse icon */
    icon?: ReactNode;
};
/**
 * @deprecated use the wayfinder accordion from @navinc/base-react-components/wayfinder instead
 *
 * Based off MUI's Accordion and takes advantage of its built in accessibility features. This component can be used uncontrolled out of the box. The uncontrolled basic accordion allows user to open all the folds. You can pass `defaultExpanded=true` to initially render with all the folds open. You can also control this accordion. A controlled accordion only opens 1 panel at a time.

 * The options passed in, of type ContentType[], allows you to disable specific folds. Passing `disabled` to the component will disable the entire accordion.

 * ```
 * type ContentType = {
 *   id: string
 *   header: ReactNode
 *   details: ReactNode
 *   disabled?: boolean
 * }
 * ```
 **/
export declare const Accordion: import("styled-components/dist/types.js").IStyledComponentBase<"web", import("styled-components").FastOmit<AccordionProps, never>> & string & Omit<({ className, open, setOpen, content, "data-testid": dataTestId, styleOverrides, icon, ...props }: AccordionProps) => import("react/jsx-runtime").JSX.Element, keyof import("react").Component<any, {}, any>>;
export {};
