var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { beforeEach, describe, expect, it, vi } from 'vitest';
import { renderWithContext } from './tests/with-app-context.js';
import { screen } from '@testing-library/react';
import { useToast, Toast, ToastProvider } from './toast-hook.js';
import userEvent from '@testing-library/user-event';
const TestToast = ({ type = 'neutralAction' }) => {
    const { showMessage } = useToast();
    return (_jsxs("div", { children: [_jsx("button", { "data-testid": "global-message-button", onClick: () => showMessage({
                    type,
                    title: 'Title',
                    copy: 'Some demo copy',
                    isDismissible: true,
                }), children: "button" }), _jsx(Toast, {})] }));
};
describe('Toast', () => {
    beforeEach(() => {
        global.URL.createObjectURL = vi.fn(() => ({ toString: () => '12345-abcde' }));
        global.URL.revokeObjectURL = vi.fn();
    });
    it('creates message when showMessage is called', () => __awaiter(void 0, void 0, void 0, function* () {
        renderWithContext(_jsx(ToastProvider, { children: _jsx(TestToast, {}) }));
        yield userEvent.click(screen.getByTestId('global-message-button'));
        expect(screen.getByText('Title')).toBeInTheDocument();
    }));
    it('clears message when dismiss button is clicked', () => __awaiter(void 0, void 0, void 0, function* () {
        renderWithContext(_jsx(ToastProvider, { children: _jsx(TestToast, {}) }));
        yield userEvent.click(screen.getByTestId('global-message-button'));
        const title = screen.getByText('Title');
        const icon = yield screen.findByTestId('banner-dismiss');
        yield userEvent.click(icon);
        expect(title).not.toBeInTheDocument();
    }));
    it('shows an error toast type', () => __awaiter(void 0, void 0, void 0, function* () {
        renderWithContext(_jsx(ToastProvider, { children: _jsx(TestToast, { type: "error" }) }));
        yield userEvent.click(screen.getByTestId('global-message-button'));
        expect(screen.getByText('Title')).toBeInTheDocument();
        expect(screen.queryByTestId('banner:neutralAction')).not.toBeInTheDocument();
        expect(screen.queryByTestId('banner:success')).not.toBeInTheDocument();
        expect(screen.getByTestId('banner:error')).toBeInTheDocument();
    }));
    it('shows a success toast type', () => __awaiter(void 0, void 0, void 0, function* () {
        renderWithContext(_jsx(ToastProvider, { children: _jsx(TestToast, { type: "success" }) }));
        yield userEvent.click(screen.getByTestId('global-message-button'));
        expect(screen.getByText('Title')).toBeInTheDocument();
        expect(screen.queryByTestId('banner:neutralAction')).not.toBeInTheDocument();
        expect(screen.queryByTestId('banner:error')).not.toBeInTheDocument();
        expect(screen.getByTestId('banner:success')).toBeInTheDocument();
    }));
});
//# sourceMappingURL=toast-hook.spec.js.map