import { ComponentType, TextareaHTMLAttributes } from 'react';
import { InputWrapperProps } from '../input-components/index.js';
import { DataAttributes } from '../../types.js';
export type InputStylesProps = {
    disabled?: boolean;
    $error?: string;
};
export declare const baseInputVariantsConfig: {
    variants: {
        disabled: {
            false: string;
            true: string;
        };
        hasValue: {
            true: string;
        };
        hasError: {
            true: string;
            false: string;
        };
    };
    compoundVariants: {
        disabled: boolean;
        hasValue: boolean;
        class: string;
    }[];
};
export declare const inputVariants: (props?: ({
    disabled?: boolean | null | undefined;
    hasValue?: boolean | null | undefined;
    hasError?: boolean | null | undefined;
} & import("class-variance-authority/types").ClassProp) | undefined) => string;
export declare const withInputStyles: <T extends {
    disabled?: boolean;
    value?: unknown;
    className?: string;
}>(Component: ComponentType<T>) => import("react").ForwardRefExoticComponent<import("react").PropsWithoutRef<T & {
    $error?: string;
}> & import("react").RefAttributes<HTMLInputElement>>;
export declare const withInputWrapper: <T extends InputStylesProps>(Component: ComponentType<T>) => import("react").ForwardRefExoticComponent<import("react").PropsWithoutRef<T & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">> & import("react").RefAttributes<HTMLInputElement>>;
export declare const StringInput: import("react").ForwardRefExoticComponent<Omit<Omit<import("react").InputHTMLAttributes<HTMLInputElement>, "type" | "value" | "checked"> & {
    value?: string;
    uncontrolled?: boolean;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const PatternInput: import("react").ForwardRefExoticComponent<Omit<Omit<import("react").InputHTMLAttributes<HTMLInputElement>, "type" | "value" | "checked"> & {
    value?: string;
    uncontrolled?: boolean;
} & {
    pattern: string;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const PhoneNumberInput: import("react").ForwardRefExoticComponent<Omit<Omit<import("../../index.js").BasePatternInputProps, "pattern" | "onChange" | "value"> & {
    value?: import("../../index.js").PhoneNumber;
    onChange?: import("react").ChangeEventHandler<Omit<HTMLInputElement, "value"> & {
        value: import("../../index.js").PhoneNumber;
    }>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const ZipCodeInput: import("react").ForwardRefExoticComponent<Omit<Omit<import("../../index.js").BasePatternInputProps, "pattern" | "onChange" | "value"> & {
    value?: import("../../index.js").ZipCode;
    onChange?: import("react").ChangeEventHandler<import("../../base-input/shared.js").TargetValue<HTMLInputElement, import("../../index.js").ZipCode>>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const ZipCodeExtendedInput: import("react").ForwardRefExoticComponent<Omit<Omit<import("../../index.js").BasePatternInputProps, "pattern" | "onChange" | "value"> & {
    value?: import("../../index.js").ZipCodeExtended;
    onChange?: import("react").ChangeEventHandler<import("../../base-input/shared.js").TargetValue<HTMLInputElement, import("../../index.js").ZipCodeExtended>>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const IntegerInput: import("react").ForwardRefExoticComponent<Omit<Omit<import("../../index.js").BaseStringInputProps, "onChange" | "value"> & {
    value?: number;
    onChange?: import("react").ChangeEventHandler<Omit<HTMLInputElement, "value"> & {
        value: number;
    }>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const AddressTypeahead: import("react").ForwardRefExoticComponent<Omit<Omit<import("react").InputHTMLAttributes<HTMLInputElement>, "type" | "value" | "checked"> & {
    value?: string;
    uncontrolled?: boolean;
} & {
    onAddressSelect?: (addr: import("../../index.js").AddressTypeaheadAddress) => void;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const USDInput: import("react").ForwardRefExoticComponent<Omit<Omit<import("../../index.js").BaseStringInputProps, "onChange" | "value"> & {
    withCents?: boolean;
    value?: import("../../index.js").USDCents;
    onChange?: import("react").ChangeEventHandler<Omit<HTMLInputElement, "value"> & {
        value: import("../../index.js").USDCents;
    }>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const DateInput: import("react").ForwardRefExoticComponent<Omit<Omit<import("react").InputHTMLAttributes<HTMLInputElement>, "type" | "onChange" | "value" | "checked"> & {
    onChange?: import("react").ChangeEventHandler<Omit<HTMLInputElement, "value"> & {
        value: Date;
    }>;
    value?: Date;
    uncontrolled?: boolean;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const TextareaInput: import("react").ForwardRefExoticComponent<Omit<import("react").ClassAttributes<HTMLTextAreaElement> & TextareaHTMLAttributes<HTMLTextAreaElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const StringField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("react").InputHTMLAttributes<HTMLInputElement>, "type" | "value" | "checked"> & {
    value?: string;
    uncontrolled?: boolean;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const PatternField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("react").InputHTMLAttributes<HTMLInputElement>, "type" | "value" | "checked"> & {
    value?: string;
    uncontrolled?: boolean;
} & {
    pattern: string;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const PhoneNumberField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("../../index.js").BasePatternInputProps, "pattern" | "onChange" | "value"> & {
    value?: import("../../index.js").PhoneNumber;
    onChange?: import("react").ChangeEventHandler<Omit<HTMLInputElement, "value"> & {
        value: import("../../index.js").PhoneNumber;
    }>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const ZipCodeField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("../../index.js").BasePatternInputProps, "pattern" | "onChange" | "value"> & {
    value?: import("../../index.js").ZipCode;
    onChange?: import("react").ChangeEventHandler<import("../../base-input/shared.js").TargetValue<HTMLInputElement, import("../../index.js").ZipCode>>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const ZipCodeExtendedField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("../../index.js").BasePatternInputProps, "pattern" | "onChange" | "value"> & {
    value?: import("../../index.js").ZipCodeExtended;
    onChange?: import("react").ChangeEventHandler<import("../../base-input/shared.js").TargetValue<HTMLInputElement, import("../../index.js").ZipCodeExtended>>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const IntegerField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("../../index.js").BaseStringInputProps, "onChange" | "value"> & {
    value?: number;
    onChange?: import("react").ChangeEventHandler<Omit<HTMLInputElement, "value"> & {
        value: number;
    }>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const AddressTypeaheadField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("react").InputHTMLAttributes<HTMLInputElement>, "type" | "value" | "checked"> & {
    value?: string;
    uncontrolled?: boolean;
} & {
    onAddressSelect?: (addr: import("../../index.js").AddressTypeaheadAddress) => void;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const USDField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("../../index.js").BaseStringInputProps, "onChange" | "value"> & {
    withCents?: boolean;
    value?: import("../../index.js").USDCents;
    onChange?: import("react").ChangeEventHandler<Omit<HTMLInputElement, "value"> & {
        value: import("../../index.js").USDCents;
    }>;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const DateField: import("react").ForwardRefExoticComponent<Omit<Omit<Omit<import("react").InputHTMLAttributes<HTMLInputElement>, "type" | "onChange" | "value" | "checked"> & {
    onChange?: import("react").ChangeEventHandler<Omit<HTMLInputElement, "value"> & {
        value: Date;
    }>;
    value?: Date;
    uncontrolled?: boolean;
} & import("react").RefAttributes<HTMLInputElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
export declare const TextareaField: import("react").ForwardRefExoticComponent<Omit<Omit<import("react").ClassAttributes<HTMLTextAreaElement> & TextareaHTMLAttributes<HTMLTextAreaElement> & {
    $error?: string;
}, "ref"> & import("react").RefAttributes<HTMLInputElement> & {
    error?: string;
} & DataAttributes & Pick<InputWrapperProps, "label" | "className" | "required" | "helperText" | "optional">, "ref"> & import("react").RefAttributes<HTMLInputElement>>;
