import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { styled } from 'styled-components';
import { Banner } from './banner.js';
import { Copy } from './copy.js';
import { Header } from './header.js';
import { Icon } from './icon.js';
import { StandardCard } from './standard-card.js';
import { Link } from './link.js';
const Section = styled.div.withConfig({ displayName: "brc-sc-Section", componentId: "brc-sc-11wfse" }) `
  display: grid;
  grid-template-columns: 1fr;
  grid-gap: 16px;
`;
const CheckedSection = styled.div.withConfig({ displayName: "brc-sc-CheckedSection", componentId: "brc-sc-1j0c1yu" }) `
  display: grid;
  grid-template-columns: 24px 1fr;
  grid-gap: 24px;
  padding: 16px 0;
`;
const CopySection = styled.div.withConfig({ displayName: "brc-sc-CopySection", componentId: "brc-sc-fvuboe" }) `
  display: grid;
  grid-gap: 16px;
`;
const BlueIcon = styled(Icon).withConfig({ displayName: "brc-sc-BlueIcon", componentId: "brc-sc-cynmhe" }) `
  color: ${({ theme }) => theme.navStatusPositive};
`;
/**
 * FQA Component for the SBA Cares Act Forgiveness calculator.
 */
export const CARESActSBAForgivenessFAQ = () => (_jsxs(Section, { "data-testid": "cares-act-sba-forgiveness-calc-faq", children: [_jsx(Header, { size: "xl", children: "PPP Loan Forgiveness for the Self-Employed Frequently Asked Questions" }), _jsx(Copy, { children: "This calculator estimates forgiveness for self-employed individuals who file Schedule C and have no employees." }), _jsx(Banner, { type: "warning", icon: "actions/circle-warning", copy: "These FAQs are for informational purposes only, are general in nature, and should not be relied upon or construed as a legal opinion or legal advice. Please keep in mind that official guidance around PPP loan forgiveness is changing rapidly and that this information is based on our current understanding of the programs. Although we will be monitoring and updating this as new information becomes available, please do not rely solely on this for your financial decisions. Borrowers are encouraged to consult with their lawyers, CPAs and Financial Advisors regarding PPP loan forgiveness." }), _jsxs(CheckedSection, { children: [_jsx(BlueIcon, { name: "actions/check-circle" }), _jsxs(CopySection, { children: [_jsx(Header, { children: "How Much Can I Pay Myself and Qualify for Forgiveness?" }), _jsxs(Copy, { children: ["Based on the", ' ', _jsx(Link, { target: "_blank", rel: "noreferrer", href: "https://home.treasury.gov/system/files/136/Interim-Final-Rule-Additional-Eligibility-Criteria-and-Requirements-for-Certain-Pledges-of-Loans.pdf", children: "guidance from Treasury" }), ", a self employed individual with no employees can apply for forgiveness for owner\u2019s compensation paid during the covered period (the eight weeks after the loan is disbursed) using 8 weeks of net profit from line 31 of the 2019 Schedule C, minus any FFCRA credit for the covered period. The basic calculation is 2019 Schedule C Line 31 net profit amount divided by 52 then multiplied by 8; however, the maximum compensation for forgiveness purposes is up to $100,000 of annualized pay for an employee or owner. (For eight weeks, that is a maximum of $15,385.)"] }), _jsx(Copy, { children: "There is no guidance yet on how or how frequently you must pay yourself during that time period. But the guidance does indicate forgiveness is based on payments during the covered period. Many experts recommend that you pay yourself during those 8 weeks by check from your business bank account so you have a clear record of this expense." })] })] }), _jsxs(CheckedSection, { children: [_jsx(BlueIcon, { name: "actions/check-circle" }), _jsxs(CopySection, { children: [_jsx(Header, { children: "What Other Expenses May Qualify for Forgiveness?" }), _jsx(Copy, { children: "In addition to owner\u2019s compensation, it appears a self-employed individual may apply for forgiveness for certain non-payroll expenses as long as they (together) don\u2019t exceed 25% of the forgiven amount. These include:" }), _jsx(StandardCard, { children: _jsxs("ul", { children: [_jsx("li", { children: _jsx(Copy, { children: "Payments of interest on mortgage obligations on real or personal property incurred before February 15, 2020, to the extent they are deductible on Form 1040 Schedule C (business mortgage payments);" }) }), _jsx("li", { children: _jsx(Copy, { children: "Rent payments on lease agreements in force before February 15, 2020, to the extent they are deductible on Form 1040 Schedule C (business rent payments); and" }) }), _jsx("li", { children: _jsx(Copy, { children: "Utility payments under service agreements dated before February 15, 2020 to the extent they are deductible on Form 1040 Schedule C (business utility payments)." }) })] }) }), _jsx(Copy, { children: "There is no guidance yet on how or how frequently you must pay yourself during that time period. But the guidance does indicate forgiveness is based on payments during the covered period. Many experts recommend that you pay yourself during those 8 weeks by check from your business bank account so you have a clear record of this expense." }), _jsx(Banner, { type: "warning", icon: "actions/circle-warning", title: "Important:", copy: "Treasury guidance indicates you must have claimed (or be entitled to claim) a deduction for such expenses on your 2019 Form 1040 Schedule C for them to be a permissible use during the eight-week period following the first disbursement of the loan. Note there is some ambiguity in the Treasury guidance regarding forgiveness for these additional expenses. Additional guidance will hopefully address this." })] })] }), _jsxs(CheckedSection, { children: [_jsx(BlueIcon, { name: "actions/check-circle" }), _jsxs(CopySection, { children: [_jsx(Header, { children: "What Reduces Forgiveness?" }), _jsx(Copy, { children: "EIDL: You must subtract any grant (advance) received from the SBA under the Economic Injury Disaster Loan (EIDL) program for forgiveness purposes. (An EIDL loan does not reduce forgiveness but should be used for a different purpose and/or timeframe.) If you have applied but not received an EIDL grant (advance), enter $0. Currently there is no guidance explaining what to do if you receive an EIDL grant after you have applied for forgiveness." }), _jsx(Copy, { children: "FFCRA: If you claimed (or will claim) a tax credit for sick or family leave under the Families First Coronavirus Response Act (the \u201CFFCRA\u201D) during the covered period (the eight weeks starting when the loan is disbursed), you must subtract that amount for purposes of calculating forgiveness." })] })] }), _jsxs(CheckedSection, { children: [_jsx(BlueIcon, { name: "actions/check-circle" }), _jsxs(CopySection, { children: [_jsx(Header, { children: "Why is My Entire Loan Not Forgivable?" }), _jsx(Copy, { children: "If you use the Nav Self Employed Forgiveness Calculator and it indicates some of your loan may not be forgivable, here are some possible reasons why:" }), _jsx(StandardCard, { children: _jsxs("ul", { children: [_jsx("li", { children: _jsxs(Copy, { children: ["You are not self-employed with no employees. This calculator is designed only for those who are self employed, filed (or will file) Schedule C for their 2019 tax return and have no employees. You\u2019ll find information on PPP forgiveness for other types of businesses, including those with employees,", ' ', _jsx(Link, { target: "_blank", rel: "noreferrer", href: "https://www.nav.com/blog/how-to-apply-for-forgiveness-for-your-paycheck-protection-program-loan-602036/", children: "here" }), "."] }) }), _jsx("li", { children: _jsxs(Copy, { children: ["You did not apply for the correct amount with your lender. If you included payments to 1099-contractors in your payroll amount when you applied for PPP, for example, you may have received more funding than current guidance suggests is allowed.", _jsx(Link, { target: "_blank", rel: "noreferrer", href: "https://home.treasury.gov/system/files/136/How-to-Calculate-Loan-Amounts.pdf", children: "This guidance" }), ' ', "explains how to calculate PPP loan amount by business type."] }) }), _jsx("li", { children: _jsx(Copy, { children: "You spent more than 25% of loan proceeds on non-payroll purposes such as mortgage interest, rent or utilities. That reduces the amount of potential forgiveness." }) }), _jsx("li", { children: _jsx(Copy, { children: "You did not spend the funds during the covered period. Currently the covered period is the eight weeks after you get the loan." }) }), _jsx("li", { children: _jsx(Copy, { children: "You refinanced an EIDL loan using PPP. Applicants were permitted to refinance an EIDL loan made by April 3, 2020 using PPP funds. However, given that the PPP application period for the self-employed did not open until April 10, 2020 we doubt that this scenario applies to many (if any) self-employed borrowers and therefore we have not included it in our calculator. If this scenario does apply to you, work with your lender." }) })] }) }), _jsx(Copy, { children: "This calculator is only designed to provide an estimate based on current guidance. Ultimately your lender will help you determine your forgivable loan amount so discuss any questions you have with them." })] })] }), _jsxs(CheckedSection, { children: [_jsx(BlueIcon, { name: "actions/check-circle" }), _jsxs(CopySection, { children: [_jsx(Header, { children: "What Happens to Amounts Not Forgiven?" }), _jsx(Copy, { children: "You may repay amounts not eligible for forgiveness early with no prepayment penalty. Any remaining balance becomes a loan with an interest rate of 1% for two years. Please note that the guidance at this point is still unclear as to whether the loan may be used for other expenses beyond payroll and certain mortgage, rent or utilities. It\u2019s a good idea to get legal advice if you want to use the remaining funds for other purposes." })] })] })] }));
//# sourceMappingURL=sba-forgiveness-faq.js.map